==> jc-1.4.0.tar.gz: java/sql/DriverPropertyInfo.h <==
// public class java.sql.DriverPropertyInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cbc8fcbc1fcebe8f java_sql_DriverPropertyInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_sql_DriverPropertyInfo_H_
#define _JC_java_sql_DriverPropertyInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_DriverPropertyInfo$sub_refs	_jc_java_sql_DriverPropertyInfo$sub_refs;
typedef struct _jc_java_sql_DriverPropertyInfo$sub_nonrefs	_jc_java_sql_DriverPropertyInfo$sub_nonrefs;
typedef struct _jc_java_sql_DriverPropertyInfo$refs	_jc_java_sql_DriverPropertyInfo$refs;
typedef struct _jc_java_sql_DriverPropertyInfo$nonrefs	_jc_java_sql_DriverPropertyInfo$nonrefs;
typedef struct _jc_java_sql_DriverPropertyInfo$object	_jc_java_sql_DriverPropertyInfo$object;

typedef const struct _jc_java_sql_DriverPropertyInfo$vmethods	_jc_java_sql_DriverPropertyInfo$vmethods;
typedef const struct _jc_java_sql_DriverPropertyInfo$vtable	_jc_java_sql_DriverPropertyInfo$vtable;
typedef const struct _jc_java_sql_DriverPropertyInfo$vtype	_jc_java_sql_DriverPropertyInfo$vtype;

// Constructors
extern void _jc_java_sql_DriverPropertyInfo$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_DriverPropertyInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_sql_DriverPropertyInfo$vmethods {
};

// Vtable
struct _jc_java_sql_DriverPropertyInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_sql_DriverPropertyInfo$vmethods	java_sql_DriverPropertyInfo;
};

// Vtype
struct _jc_java_sql_DriverPropertyInfo$vtype {
	_jc_type			type;
	_jc_java_sql_DriverPropertyInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_DriverPropertyInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*description;
	struct _jc_java_lang_String$object	*value;
	_jc_object_array	*choices;
};

// Reference instance fields (object)
struct _jc_java_sql_DriverPropertyInfo$refs {
    _jc_java_sql_DriverPropertyInfo$sub_refs	java_sql_DriverPropertyInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_DriverPropertyInfo$sub_nonrefs {
	jboolean	required;
};

// Non-reference instance fields (object)
struct _jc_java_sql_DriverPropertyInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_sql_DriverPropertyInfo$sub_nonrefs	java_sql_DriverPropertyInfo;
};

// Object instance structure
struct _jc_java_sql_DriverPropertyInfo$object {
	_jc_java_sql_DriverPropertyInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_DriverPropertyInfo$vtype	*vtype;
	_jc_java_sql_DriverPropertyInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_DriverPropertyInfo$vtype _jc_java_sql_DriverPropertyInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_DriverPropertyInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_DriverPropertyInfo$class_object;

#endif	/* _JC_java_sql_DriverPropertyInfo_H_ */

==> jc-1.4.6.tar.gz: java/sql/DriverPropertyInfo.h <==
// public class java.sql.DriverPropertyInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cbc8fcbc1fcebe8f java_sql_DriverPropertyInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_sql_DriverPropertyInfo_H_
#define _JC_java_sql_DriverPropertyInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_sql_DriverPropertyInfo$sub_refs	_jc_java_sql_DriverPropertyInfo$sub_refs;
typedef struct _jc_java_sql_DriverPropertyInfo$sub_nonrefs	_jc_java_sql_DriverPropertyInfo$sub_nonrefs;
typedef struct _jc_java_sql_DriverPropertyInfo$refs	_jc_java_sql_DriverPropertyInfo$refs;
typedef struct _jc_java_sql_DriverPropertyInfo$nonrefs	_jc_java_sql_DriverPropertyInfo$nonrefs;
typedef struct _jc_java_sql_DriverPropertyInfo$object	_jc_java_sql_DriverPropertyInfo$object;

typedef const struct _jc_java_sql_DriverPropertyInfo$vmethods	_jc_java_sql_DriverPropertyInfo$vmethods;
typedef const struct _jc_java_sql_DriverPropertyInfo$vtable	_jc_java_sql_DriverPropertyInfo$vtable;
typedef const struct _jc_java_sql_DriverPropertyInfo$vtype	_jc_java_sql_DriverPropertyInfo$vtype;

// Constructors
extern void _jc_java_sql_DriverPropertyInfo$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_sql_DriverPropertyInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_sql_DriverPropertyInfo$vmethods {
};

// Vtable
struct _jc_java_sql_DriverPropertyInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_sql_DriverPropertyInfo$vmethods	java_sql_DriverPropertyInfo;
};

// Vtype
struct _jc_java_sql_DriverPropertyInfo$vtype {
	_jc_type			type;
	_jc_java_sql_DriverPropertyInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_DriverPropertyInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*description;
	struct _jc_java_lang_String$object	*value;
	_jc_object_array	*choices;
};

// Reference instance fields (object)
struct _jc_java_sql_DriverPropertyInfo$refs {
    _jc_java_sql_DriverPropertyInfo$sub_refs	java_sql_DriverPropertyInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_DriverPropertyInfo$sub_nonrefs {
	jboolean	required;
};

// Non-reference instance fields (object)
struct _jc_java_sql_DriverPropertyInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_sql_DriverPropertyInfo$sub_nonrefs	java_sql_DriverPropertyInfo;
};

// Object instance structure
struct _jc_java_sql_DriverPropertyInfo$object {
	_jc_java_sql_DriverPropertyInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_DriverPropertyInfo$vtype	*vtype;
	_jc_java_sql_DriverPropertyInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_DriverPropertyInfo$vtype _jc_java_sql_DriverPropertyInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_DriverPropertyInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_DriverPropertyInfo$class_object;

#endif	/* _JC_java_sql_DriverPropertyInfo_H_ */
